@@ -12,7 +12,7 @@ function (out, lambda = out$lambda, y = NULL, yM=NULL, verbose=FALSE)
 
 #
 # Determine whether to collapse onto means of replicates ( using y)
-# or if the data as replicate means have been passed use yM.
+# if the data has been passed use as the replicate means (yM) use that.
 # If both y and YM are null then just use out$yM 
 # For readability of this function, all this tortured logic happens in 
 #  Krig.ynew. 
@@ -22,25 +22,45 @@ function (out, lambda = out$lambda, y = NULL, yM=NULL, verbose=FALSE)
 
     nt <- out$nt
     np <- out$np
+    ndata<- ncol( temp.yM)
     u <- NA
     call.name<- out$cov.function.name
-
+    
+    if( verbose){
+      cat("dimension of yM in Krig.coef", fill=TRUE)
+      print( dim( temp.yM))}
     
 #
 #   case when knots= unqiue x's
 # any lambda
 #    
     if (out$decomp == "WBW") {
-        u <- c(rep(0, out$nt), t(out$matrices$V) %*% qr.q2ty(out$matrices$qr.T, 
-            out$W2%d*% temp.yM))
-        beta <- out$matrices$G %*% ((1/(1 + lambda * out$matrices$D)) * 
-            u)
-        temp.c <- c(qr.qy(out$matrices$qr.T, c(rep(0, nt), beta[(nt + 
-            1):np])))
-        temp.c <- out$W2%d*%temp.c 
+# pad u with zeroes that corresond to null space basis functions
+# this makes it compatible with the DR decomposition.
+      
+        u <- rbind(
+                   matrix(0, nrow=out$nt, ncol=ndata ),
+                   t(out$matrices$V) %*%
+                   qr.q2ty(out$matrices$qr.T,out$W2%d*% temp.yM))
+#       
+#old code   beta <- out$matrices$G %*% ((1/(1 + lambda * out$matrices$D))%d*%u)
+#
+        ind<- (nt + 1):np
+        D2<- out$matrices$D[ind]
+#        
+# note use of efficient diagonal multiply in next line
+        temp2 <- (D2/(1 + lambda* D2))%d*%u[ind,]
+
+
+        beta2 <- out$matrices$V %*%temp2 
+
+        temp.c<- rbind( matrix(0, nrow=nt, ncol=ndata ), beta2 )
+        temp.c <- qr.qy(out$matrices$qr.T, temp.c)
+        temp.c <- out$W2%d*%temp.c
+
         temp <- temp.yM - do.call(call.name, 
-             c(out$args, list(x1 = out$knots, x2 = out$knots, 
-                C = temp.c)))
+                c(out$args, list(x1 = out$knots, x2 = out$knots, 
+                   C = temp.c)))
         temp <- out$W2%d*%temp
         temp.d <- qr.coef(out$matrices$qr.T, temp)
     }
@@ -58,14 +78,14 @@ function (out, lambda = out$lambda, y = NULL, yM=NULL, verbose=FALSE)
         do.call(call.name, c(out$args, list(x1 = out$xM, x2 =out$knots) )  )
                 )
 
-        u <- t(out$matrices$G) %*% t(X) %*% (out$weightsM * 
-            temp.yM)
-        beta <- out$matrices$G %*% ((1/(1 + lambda * out$matrices$D)) * 
-            u)
-        temp.d <- beta[1:nt]
-        temp.c <- beta[(nt + 1):np]
+        u <- t(out$matrices$G) %*% t(X) %*% (out$weightsM %d*% temp.yM)
+        beta <- out$matrices$G %*%
+                ( (1/(1 + lambda * out$matrices$D))%d*%u)
+        temp.d <- beta[1:nt,]
+        temp.c <- beta[(nt + 1):np,]
         temp <- X %*% out$matrices$G %*% u
         temp <- sum(out$weightsM * (temp.yM - temp)^2)
+#### ????
         out2$pure.ss <- temp + out2$pure.ss
     }
 
@@ -74,8 +94,7 @@ function (out, lambda = out$lambda, y = NULL, yM=NULL, verbose=FALSE)
 #    
     if (out$decomp == "cholesky") {
         if (lambda != out$matrices$lambda) {
-            stop("New lambda can not be used with cholesky decomposition")
-        }
+            stop("New lambda can not be used with cholesky decomposition")}
 
         Tmatrix <-  do.call(out$null.function.name, 
                          c(out$null.args, list(x=out$knots, Z=out$ZM) ) )
@@ -120,8 +139,9 @@ function (out, lambda = out$lambda, y = NULL, yM=NULL, verbose=FALSE)
     }
 
     
-    return(
-           c(out2, list(c = c(temp.c), d = c(temp.d), u = c(u)))
-           )
+    return( list(c = temp.c, d = temp.d,
+                  shat.rep = out2$shat.rep, 
+                  shat.pure.error = out2$shat.pure.error,
+                  pure.ss = out2$pure.ss))         
 }
 
