@@ -20,6 +20,7 @@ function(out, y=NULL, yM=NULL)
 		shat.pure.error <- NA
 
 		pure.ss <- 0
+
 # if no y's are given then it is assumed that one should use the
 # yM from the original data used to create the Krig object
 
@@ -31,29 +32,32 @@ function(out, y=NULL, yM=NULL)
 # case when yM is passed no calculations are needed
 #
         if( !is.null(yM) ){
-                return(list(yM = yM, shat.rep = NA, shat.pure.error = NA,
+                return(list(yM = as.matrix(yM),
+                            shat.rep = NA, shat.pure.error = NA,
                         pure.ss = 0))
         }
 
 
+#
+# no reps case
+#
+	if(length(unique(out$rep.info)) == out$N) {
+		return(list(yM = as.matrix(y),
+                            shat.rep = NA, shat.pure.error = NA,
+			pure.ss = 0))
+	}
 # 
 #  check that y is the right length
 #
 
 	if(length(y) != out$N) {
-		stop(" the new Y vector is the wrong length!")
-	}
-#
-# no reps case
-#
-	if(length(unique(out$rep.info)) == out$N) {
-		return(list(yM = y, shat.rep = NA, shat.pure.error = NA,
-			pure.ss = 0))
+		stop(" the new y vector is the wrong length!")
 	}
 #
 # case when full y data is passed and replicate means need to be found
 #
 	if(length(unique(out$rep.info)) < out$N) {
+           
 #
 # calculate means by pooling Replicated obseravations but use the
 # the right weighting. 
@@ -67,6 +71,5 @@ function(out, y=NULL, yM=NULL)
 			rep.info.aov$SSE))
 	}
 
-     stop(" error should not get here")
 
 }
