@@ -1,3 +1,8 @@
+# fields, Tools for spatial data
+# Copyright 2004-2007, Institute for Mathematics Applied Geosciences
+# University Corporation for Atmospheric Research
+# Licensed under the GPL -- www.gpl.org/licenses/gpl.html
+
 "sim.Krig.standard" <-
 function( object, xp, M=1, verbose=FALSE, sigma2=NA, rho=NA) {
 
@@ -93,7 +98,11 @@ function( object, xp, M=1, verbose=FALSE, sigma2=NA, rho=NA) {
     if (object$correlation.model) {
       if( !is.na( object$sd.obj[1]) ) {temp.sd<-predict( object$sd.obj, x)}
     }
+#
+#  Define W2i for simulating errors. 
+#
 
+  W2i <- Krig.make.Wi( object)$W2i
 
   for(  k in 1: M){
 
@@ -115,7 +124,7 @@ function( object, xp, M=1, verbose=FALSE, sigma2=NA, rho=NA) {
 
 # create synthetic data
 
-     y.synthetic<- h.data + rnorm(N)*sqrt( sigma2/object$weightsM)
+     y.synthetic<- h.data + sqrt(sigma2)* W2i%d*%rnorm(N)
 
 # predict at xp using these data
 # and subtract from "true" value 
